==> midori-0.0.8.tar.gz: midori-0.0.8/src/helpers.h <==
/* Copyright (C) 2007 Christian Dywan <christian at twotoasts dot de>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. */

#ifndef __HELPERS_H__
#define __HELPERS_H__ 1

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>
#include "sokoke.h"
#include "browser.h"
#include "debug.h"

GtkIconTheme* get_icon_theme(GtkWidget*);

GtkWidget* menu_item_new(const gchar*, const gchar*, const gchar*
 , const gchar*, GdkModifierType, GCallback, gboolean, gpointer);

GtkToolItem* tool_button_new(const gchar*, const gchar*
 , gboolean, gboolean, GCallback, const gchar*, gpointer);

GtkWidget* check_menu_item_new(const gchar*, const gchar*, const gchar*
 , GdkModifierType, GCallback, gboolean, gboolean, CBrowser*);

GtkWidget* radio_button_new(GtkRadioButton*, const gchar*);

void entry_setup_completion(GtkEntry*);

void entry_completion_append(GtkEntry*, const gchar*);

GtkWidget* get_current_document(CBrowser*);

gint get_document_index(GtkWidget*, CBrowser*);

void update_favicon(CBrowser*);

void update_security(CBrowser*);

void update_visibility(CBrowser*, gboolean);

void action_set_active(const gchar*, gboolean, CBrowser*);

void action_set_sensitive(const gchar*, gboolean, CBrowser*);

void action_set_visible(const gchar*, gboolean, CBrowser*);

void update_statusbar_text(CBrowser*);

void update_gui_state(CBrowser*);

void update_feeds(CBrowser*);

void update_search_engines(CBrowser*);

void update_status_message(CBrowser*, const gchar*);

void update_browser_actions(CBrowser*);

gchar* magic_uri(const gchar*, const gchar*);

gchar* get_default_font(void);

GtkToolbarStyle config_to_toolbarstyle();

GtkToolbarStyle config_to_toolbariconsize(guint);


#endif /* !__HELPERS_H__ */

==> midori-0.0.10.tar.gz: midori-0.0.10/src/helpers.h <==
/* Copyright (C) 2007 Christian Dywan <christian at twotoasts dot de>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. */

#ifndef __HELPERS_H__
#define __HELPERS_H__ 1

#include "ui.h"
#include "sokoke.h"

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>

GtkIconTheme* get_icon_theme(GtkWidget*);

GtkWidget* menu_item_new(const gchar*, const gchar*, const gchar*
 , const gchar*, GdkModifierType, GCallback, gboolean, gpointer);

GtkToolItem* tool_button_new(const gchar*, const gchar*
 , gboolean, gboolean, GCallback, const gchar*, gpointer);

GtkWidget* check_menu_item_new(const gchar*, const gchar*, const gchar*
 , GdkModifierType, GCallback, gboolean, gboolean, CBrowser*);//...

GtkWidget* radio_button_new(GtkRadioButton*, const gchar*);

void show_error(const gchar*, const gchar*, CBrowser*);

gboolean spawn_protocol_command(const gchar*, const gchar*);

void entry_setup_completion(GtkEntry*);

void entry_completion_append(GtkEntry*, const gchar*);

GtkWidget* get_current_document(CBrowser*);

gint get_document_index(GtkWidget*, CBrowser*);

void update_favicon(CBrowser*);

void update_security(CBrowser*);

void update_visibility(CBrowser*, gboolean);

void action_set_active(const gchar*, gboolean, CBrowser*);

void action_set_sensitive(const gchar*, gboolean, CBrowser*);

void action_set_visible(const gchar*, gboolean, CBrowser*);

void update_statusbar_text(CBrowser*);

void update_gui_state(CBrowser*);

void update_feeds(CBrowser*);

void update_search_engines(CBrowser*);

void update_status_message(const gchar*, CBrowser*);

void update_browser_actions(CBrowser*);

gchar* magic_uri(const gchar*, const gchar*);

gchar* get_default_font(void);

GtkToolbarStyle config_to_toolbarstyle();

GtkToolbarStyle config_to_toolbariconsize(gboolean);


#endif /* !__HELPERS_H__ */
